@@ -28,6 +28,7 @@ async def bili_keyword(group_id, text):
                     break
 
         # 获取视频详细信息
+        msg, vurl = "", ""
         if "view?" in url:
             msg, vurl = await video_detail(url, page)
         elif "bangumi" in url:
@@ -36,7 +37,7 @@ async def bili_keyword(group_id, text):
             msg, vurl = await live_detail(url)
         elif "article" in url:
             msg, vurl = await article_detail(url, page)
-        else:
+        elif "dynamic" in url:
             msg, vurl = await dynamic_detail(url)
 
         # 避免多个机器人解析重复推送
@@ -48,7 +49,7 @@ async def bili_keyword(group_id, text):
         if last_vurl == vurl:
             return
     except Exception as e:
-        msg = "Error: {}".format(type(e))
+        msg = "bili_keyword Error: {}".format(type(e))
     return msg
 
 
@@ -66,7 +67,8 @@ async def b23_extract(text):
 
 async def extract(text: str):
     try:
-        page = re.compile(r"\?p=\d+").search(text)
+        url = ""
+        page = re.compile(r"([?&]|&amp;)p=\d+").search(text)
         aid = re.compile(r"av\d+", re.I).search(text)
         bvid = re.compile(r"BV([A-Za-z0-9]{10})+", re.I).search(text)
         epid = re.compile(r"ep\d+", re.I).search(text)
@@ -103,7 +105,7 @@ async def extract(text: str):
             url = f"https://api.vc.bilibili.com/dynamic_svr/v1/dynamic_svr/get_dynamic_detail?dynamic_id={dynamic_id[2]}"
         return url, page
     except Exception:
-        return None, None
+        return "", None
 
 
 async def search_bili_by_title(title: str):
@@ -133,10 +135,10 @@ async def video_detail(url, page):
         vurl = f"https://www.bilibili.com/video/av{res['aid']}"
         title = f"\n标题：{res['title']}\n"
         if page:
-            page = page[0]
-            p = int(page[len("?p=") :])
+            page = page[0].replace("&amp;", "&")
+            p = int(page[3:])
             if p <= len(res["pages"]):
-                vurl += page + ""
+                vurl += f"?p={p}"
                 part = res["pages"][p - 1]["part"]
                 if part != res["title"]:
                     title += f"小标题：{part}\n"
